      SUBROUTINE XEGPMT
*.
*...XEGPMT   Define geometry of the PMT for the liq. Xe photon detector
*.
*. SEQUENCE  : GCCUTS GCFLAG GCLIST GCONST
*.           : GMMATM RCREP
*. CALLS     : GSATT  GSPOS  GSVOLU REPORT
*. CALLED    : GMGEOM
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.03
*. CREATED   : 17-Mar-00
*. LAST MOD  : 05-Jul-02
*.
*. Modification Log.
*. 09-Jul-03   R.Sawada        (V1.05) Included Tip tube Base,and Filler in XPMT
*. 21-Apr-03   R.Sawada        (V1.04) Modified geometry and Add filler
*. 05-Jul-02   K.Ozone         (V1.03) Removed QEFF initialization.
*.                             It was moved to lpiffr.F.
*. 23-Feb-02   K.Ozone         (V1.02) QE*CE was changed 0.079 to 0.05.
*. 16-May-00   T.Mashimo       (V1.01) SPxxxx -> VPxxxx.
*. 17-Mar-00   T.Mashimo       (V1.00) First version.
*.
*.**********************************************************************
*.
*.   The z-axis of the local coordinate system runs along the axis of
*. the PMT.  The +z is on the side of the quartz glass window.
*.   The volume for the quartz glass window, 'XPWD' are not made
*. a daughter of the volume 'XPMT'.  The caller should put XPMT and
*. XPWD at the same level in the volume tree.  This is to facilitate
*. the tracking of scintillation photons and also to allow putting
*. liquid Xe surrounding the XPWD.
*. 
*.
#include "declare.inc"
#include "geant321/gconst.inc"
#include "geant321/gccuts.inc"
#include "geant321/gcflag.inc"
#include "geant321/gclist.inc"
#include "rcrep.inc"
#include "gmmatm.inc"
#include "xecpmt.inc"
#include "lpflag.inc"
*
      INTEGER IVOL, I
      REAL    ZPXPDY
      REAL    ZPXPFL
      REAL    ZPXPVA
      REAL    ZPOSBS
      REAL    ZPOSPH
*
*-- Initialization
*
      VPXPWD(1) = 0.000
      VPXPWD(2) = 2.525
      VPXPWD(3) = 0.150
      VPXPMT(1) = 0.000
      VPXPMT(2) = 2.780
      VPXPMT(3) = 2.0
      VPXPSS(2) = VPXPMT(2)
      VPXPSS(1) = VPXPSS(2) - 0.0160
      VPXPSS(3) = 1.45
      VPXPDY(1) = 0.000
      VPXPDY(2) = 2.550
      VPXPDY(3) = 0.0063

      VPXPPH(1) =  2.4
      VPXPPH(2) =  VPXPMT(2)
      VPXPPH(3) =  VPXPMT(3)-1.45
      VPXPFL(1) =  0
      VPXPFL(2) =  VPXPMT(2)
      VPXPFL(3) =  VPXPMT(3) - 1.15
*
      VPXPGL(1) = 0.
      VPXPGL(2) = 360.
      VPXPGL(3) = 10    
      VPXPGL(4) = 0.0
      VPXPGL(5) = 1.0 
      VPXPGL(6) = VPXPSS(2) - 0.0160
      VPXPGL(7) = -0.05
      VPXPGL(8) = 0.5 
      VPXPGL(9) = VPXPSS(2) - 0.0160
      VPXPGL(10) = -0.2
      VPXPGL(11) = 0.0
      VPXPGL(12) = VPXPSS(2) - 0.0160 
      VPXPGL(13) = -0.25
      VPXPGL(14) = 0.0
      VPXPGL(15) = 0.5
      VPXPGL(16) = -0.5
      VPXPGL(17) = 0.0
      VPXPGL(18) = 0.3
      VPXPGL(19) = -0.8
      VPXPGL(20) = 0.0
      VPXPGL(21) = 0.3
      VPXPGL(22)=-1.1
      VPXPGL(23)=0.
      VPXPGL(24)=0.3
      VPXPGL(25)=-1.25
      VPXPGL(26)=0.
      VPXPGL(27)=0.27
      VPXPGL(28)=-1.4
      VPXPGL(29)=0.
      VPXPGL(30)=0.05
      VPXPGL(31)=-1.5
      VPXPGL(32)=0.
      VPXPGL(33)=0.
*
      VPXPBS(1) = 0.5
      VPXPBS(2) = 2.240
      VPXPBS(3) = 0.1
      ZSXPDY = VPXPMT(3) - 0.155
      ZGXPDY = 0.080
      ZPXPGL = VPXPMT(3) - 2.1

      ZPOSBS = VPXPMT(3) - 2.9 - VPXPBS(3)
      ZPOSPH = -VPXPMT(3) + VPXPPH(3)
      ZPXPFL = -VPXPMT(3) + VPXPFL(3)
*
      RCATH  = 4.5/2.
*
*-- Quartz glass window
*
      CALL GSVOLU('XPWD', 'TUBE', TMXPWD, VPXPWD, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPWD:'', I8)') IVOL
         CALL REPORT('XEGPMT', 1, 'ERROR')
      END IF
      CALL GSATT('XPWD', 'SEEN', 1)
*
*-- Mother volume
*
      CALL GSVOLU('XPMT', 'TUBE', TMVACU, VPXPMT, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPMT:'', I8)') IVOL
         CALL REPORT('XEGPMT', 2, 'ERROR')
      END IF
      CALL GSATT('XPMT', 'SEEN', 0)
*
*-- SUS tube
*
      CALL GSVOLU('XPSS', 'TUBE', TMXPSS, VPXPSS, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPWD:'', I8)') IVOL
         CALL REPORT('XEGPMT', 3, 'ERROR')
      END IF
      CALL GSATT('XPSS', 'SEEN', 1)
      ZPXPSS = VPXPMT(3) - VPXPSS(3)
      CALL GSPOS('XPSS', 1, 'XPMT', 0., 0., ZPXPSS, 0, 'ONLY')
*
*-- Dynodes
*
      CALL GSVOLU('XPDY', 'TUBE', TMXPDY, VPXPDY, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPDY:'', I8)') IVOL
         CALL REPORT('XEGPMT', 4, 'ERROR')
      END IF
      CALL GSATT('XPDY', 'SEEN', 1)
      ZPXPDY = ZSXPDY
      DO 100 I = 1, 13
         CALL GSPOS('XPDY', I, 'XPMT', 0., 0., ZPXPDY, 0, 'ONLY')
         ZPXPDY = ZPXPDY - ZGXPDY
 100  CONTINUE
*
*-- Stem (glass)
*
      CALL GSVOLU('XPGL', 'PCON', TMXPGL, VPXPGL, 33, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPGL:'', I8)') IVOL
         CALL REPORT('XEGPMT', 5, 'ERROR')
      END IF
      CALL GSATT('XPGL', 'SEEN', 1)
      CALL GSPOS('XPGL', 1, 'XPMT', 0., 0., ZPXPGL, 0, 'ONLY')


*
*-- Base (G10)
*
      CALL GSVOLU('XPBS', 'TUBE', TMXPBS, VPXPBS, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPWD:'', I8)') IVOL
         CALL REPORT('XEGPMT', 6, 'ERROR')
      END IF
      CALL GSATT('XPBS', 'SEEN', 1)
      CALL GSPOS('XPBS', 1, 'XPMT',
     +     0, 0, ZPOSBS, 0, 'ONLY')

*
*__ Holder
*
      CALL GSVOLU('XPPH', 'TUBE', TMXPBS, VPXPPH, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPPH:'', I8)') IVOL
         CALL REPORT('XEGPMT', 6, 'ERROR')
      END IF
      CALL GSATT('XPPH', 'SEEN', 1)
      CALL GSPOS('XPPH', 1, 'XPMT',
     +     0, 0, ZPOSPH, 0, 'ONLY')
      
*
*-- Filler or Xenon
*
      IF(FILLERON .EQ. 1) THEN
         CALL GSVOLU('XPFL', 'TUBE', TMXFIL, VPXPFL, 3, IVOL)
      ELSE 
         CALL GSVOLU('XPFL', 'TUBE', TMXELQ, VPXPFL, 3, IVOL)
      END IF
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPFL:'', I8)') IVOL
         CALL REPORT('XEGPMT', 6, 'ERROR')
      END IF
      CALL GSATT('XPFL', 'SEEN', 1)
      CALL GSPOS('XPFL', 1, 'XPMT', 0., 0., ZPXPFL, 0, 'MANY')
*
  999 CONTINUE
      RETURN
      END
